R_altrep_Duplicate_method_t

Type Alias R_altrep_Duplicate_method_t 

pub type R_altrep_Duplicate_method_t = Option<unsafe extern "C" fn(arg1: SEXP, arg2: Rboolean) -> SEXP>;
Must return a copy (see duplicate) of x that can be altered independently of x, ignoring the attributes. R will duplicate and install the attributes by itself.

May return a null pointer, in which case R will produce a materialised copy of the object by itself. The default method returns a null pointer.

Aliased Type

pub enum R_altrep_Duplicate_method_t {
    None,
    Some(unsafe extern "C" fn(*mut SEXPREC, Rboolean) -> *mut SEXPREC),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut SEXPREC, Rboolean) -> *mut SEXPREC)

Some value of type T.