R_altrep_Inspect_method_t

Type Alias R_altrep_Inspect_method_t 

pub type R_altrep_Inspect_method_t = Option<unsafe extern "C" fn(arg1: SEXP, arg2: c_int, arg3: c_int, arg4: c_int, arg5: Option<unsafe extern "C" fn(arg1: SEXP, arg2: c_int, arg3: c_int, arg4: c_int)>) -> Rboolean>;
This method will be called from .Internal(inspect(…)) after printing the standard SEXP header contents; it can then print (see Rprintf) additional information specific to this ALTREP class. When starting a new line, this method must respect the output indentation pre. Printing the vector elements, if done, should be subject to the recommended vector printing length pvec. The method should call inspect_subtree for child elements, subject to the limits in deep. If the return value is TRUE, R will consider the value inspected and won’t access its contents; otherwise R will then inspect the contents of x as if it was an ordinary value. Either way, R will then take care of inspecting the attributes of x. The default method returns FALSE. Versions: Appeared in 3.5.0.

Aliased Type

pub enum R_altrep_Inspect_method_t {
    None,
    Some(unsafe extern "C" fn(*mut SEXPREC, i32, i32, i32, Option<unsafe extern "C" fn(*mut SEXPREC, i32, i32, i32)>) -> Rboolean),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut SEXPREC, i32, i32, i32, Option<unsafe extern "C" fn(*mut SEXPREC, i32, i32, i32)>) -> Rboolean)

Some value of type T.