R_altrep_Serialized_state_method_t

Type Alias R_altrep_Serialized_state_method_t 

pub type R_altrep_Serialized_state_method_t = Option<unsafe extern "C" fn(arg1: SEXP) -> SEXP>;
Must prepare and return a representation of x that can be given to the Unserialize methods below in order to recreate it.

May return a null pointer, making R materialise the object when saving it. The default method returns a null pointer.

Aliased Type

pub enum R_altrep_Serialized_state_method_t {
    None,
    Some(unsafe extern "C" fn(*mut SEXPREC) -> *mut SEXPREC),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut SEXPREC) -> *mut SEXPREC)

Some value of type T.