pub type R_altrep_UnserializeEX_method_t = Option<unsafe extern "C" fn(arg1: SEXP, arg2: SEXP, arg3: SEXP, arg4: c_int, arg5: c_int) -> SEXP>;Expand description
Like the Unserialize method above, but must also take care of setting the attributes, the levels field and the object bit on the return value. This is likely impossible to implement within the confines of the R API. The default method calls the Unserialize method, sets the attributes, the object bit, and the levels field, and returns the result.
Aliased Type
pub enum R_altrep_UnserializeEX_method_t {
None,
Some(unsafe extern "C" fn(*mut SEXPREC, *mut SEXPREC, *mut SEXPREC, i32, i32) -> *mut SEXPREC),
}