R_altvec_Extract_subset_method_t

Type Alias R_altvec_Extract_subset_method_t 

pub type R_altvec_Extract_subset_method_t = Option<unsafe extern "C" fn(arg1: SEXP, arg2: SEXP, arg3: SEXP) -> SEXP>;
Must allocate and return a new vector containing the result of subsetting, x[indx], following the usual semantics of the [ operator for numeric subscripts. For values outside the range of x, missing values must be returned (R_NilValue for VECSXP lists, 0 for RAWSXP vectors). May also return a null pointer (see above).

The default method always returns a null pointer. Versions: Appeared in 3.5.0.

Aliased Type

pub enum R_altvec_Extract_subset_method_t {
    None,
    Some(unsafe extern "C" fn(*mut SEXPREC, *mut SEXPREC, *mut SEXPREC) -> *mut SEXPREC),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*mut SEXPREC, *mut SEXPREC, *mut SEXPREC) -> *mut SEXPREC)

Some value of type T.