pub type R_altrep_Coerce_method_t = Option<unsafe extern "C" fn(arg1: SEXP, arg2: SEXPTYPE) -> SEXP>;Expand description
Must return an R value of SEXPTYPE type containing the result of conversion of x into that type, ignoring the attributes. May return a null pointer, making R perform the conversion as usual (see coerceVector). The default method returns a null pointer.
Aliased Type
pub enum R_altrep_Coerce_method_t {
None,
Some(unsafe extern "C" fn(*mut SEXPREC, SEXPTYPE) -> *mut SEXPREC),
}