pub type R_altrep_DuplicateEX_method_t = Option<unsafe extern "C" fn(arg1: SEXP, arg2: Rboolean) -> SEXP>;Expand description
Like the Duplicate method above, but must duplicate the attributes in the same manner. May return a null pointer, in which case R will produce a materialised copy of the object by itself. The default method calls the Duplicate method, duplicates the attributes of x and installs them onto the return value.
Aliased Type
pub enum R_altrep_DuplicateEX_method_t {
None,
Some(unsafe extern "C" fn(*mut SEXPREC, Rboolean) -> *mut SEXPREC),
}