pub type R_altrep_Duplicate_method_t = Option<unsafe extern "C" fn(arg1: SEXP, arg2: Rboolean) -> SEXP>;Expand description
Must return a copy (see duplicate) of x that can be altered independently of x, ignoring the attributes. R will duplicate and install the attributes by itself.
May return a null pointer, in which case R will produce a materialised copy of the object by itself. The default method returns a null pointer.
Aliased Type
pub enum R_altrep_Duplicate_method_t {
None,
Some(unsafe extern "C" fn(*mut SEXPREC, Rboolean) -> *mut SEXPREC),
}