pub type R_altrep_Serialized_state_method_t = Option<unsafe extern "C" fn(arg1: SEXP) -> SEXP>;Expand description
Must prepare and return a representation of x that can be given to the Unserialize methods below in order to recreate it.
May return a null pointer, making R materialise the object when saving it. The default method returns a null pointer.
Aliased Type
pub enum R_altrep_Serialized_state_method_t {
None,
Some(unsafe extern "C" fn(*mut SEXPREC) -> *mut SEXPREC),
}