pub type R_altvec_Dataptr_or_null_method_t = Option<unsafe extern "C" fn(arg1: SEXP) -> *const c_void>;Expand description
Like the Dataptr method above, but the method may return a null pointer to indicate a preference for *_Elt (see REAL_ELT) and *_Get_region (see REAL_GET_REGION) methods instead of full buffer access. The return value will not be used to modify x. The default method always returns a null pointer.
Aliased Type
pub enum R_altvec_Dataptr_or_null_method_t {
None,
Some(unsafe extern "C" fn(*mut SEXPREC) -> *const c_void),
}